<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$t->set_var(array(

"Product_not_found" => "Product not found",
"Sorry_product_not_found" => "Sorry, the product you are looking for was not found on file.  Please try our <a href=\"" . "$CFG->wwwroot" . "/shopping/\">shopping catalog</a> to find what you are looking for.",
"Add_to_cart" => "+ Add to cart",
"Add_to_Shopping_Cart" => "+ Add to Shopping Cart",
"In_the_cart" => "In the cart",
"Categories_Browsing" => "Categories Browsing",
"Your_shopping_cart_is_empty" => "Your shopping cart is empty, <a href=\"" . "$CFG->wwwroot" . "/shopping/\">see the products catalog</a>.",
"Step_1_Enter_Billing_Information" => "Step 1. Enter Billing Information",
"Step_2_Comments_and_Special_Instructions" => "Step 2. Comments / Special Instructions",
"Next_Step" => "Next Step",
"Billing_Details" => "Billing Details",
"Continue_Shopping" => "Continue Shopping",
"Recalculate_Cart" => "Recalculate Cart",
"Empty_the_Cart" => "Empty the Cart",
"Your_Shopping_Cart_Contains" => "Your Shopping Cart Contains",
"Purchase_Now" => "Purchase Now",
"min" => "min &nbsp;",
"max" => "&nbsp; max",
"Subset_or_Equal" => "",

));

?>
